clear all
tic
IC=readtable('Anions.xls','sheet','Data','range','A1:H56');

leaching_data=IC.Chloride;
leaching_data=leaching_data(1:48);
T=reshape(leaching_data,[4 12])';
save("T.mat",'T')
t0=[0.083 0.208 1 1.978 3.022 4 4.988 6 6.999 8.014 9.003 10];

%% Calculate initial amount
Vl=[486.04 469.76 498.79 504.75]/1000;
Tota_diffused=cumsum(T) %in mg/l;
Tota_diffused=Tota_diffused-Tota_diffused(:,1);
Total_diffused_mg=Tota_diffused(end,:).*Vl; %total leached in mg
total_left=[0.58 4.647 4.737 5.486]; %in mg
total_left=total_left-total_left(1);%in mg
total_washed_mg=Tota_diffused(2,:).*Vl; %extract second row
A0=total_left+Total_diffused_mg;


f1000=figure
plot(t0,Tota_diffused(:,1).*Vl(1),'k^-','LineWidth',1.2)
hold on
plot(t0,Tota_diffused(:,2).*Vl(2),'ro-','LineWidth',1.2)

plot(t0,Tota_diffused(:,3).*Vl(3),'bo-','LineWidth',1.2)
plot(t0,Tota_diffused(:,4).*Vl(4),'go-','LineWidth',1.2)
ylabel("Absolute amount Cl [mg]");
xlabel("time (days)");
grid on
set(gca,'FontSize',16)
legend("Control","S1","S2","S3","fontsize",14,'location','southeast')
saveas(f1000,'Cl vs t_absolute.png')

%% Concentration vs time
f6=figure
plot(t0,T(:,1)','k^-','LineWidth',1.2)
hold on
plot(t0,T(:,2)','ro-','LineWidth',1.2)

plot(t0,T(:,3)','bo-','LineWidth',1.2)
plot(t0,T(:,4)','go-','LineWidth',1.2)
ylabel("Cl^- [mg/L]");
xlabel("Time [days]");
grid on
set(gca,'FontSize',16)
legend("Control","S1","S2","S3","fontsize",14)
exportgraphics(f6,'C vs t_cl.tiff','Resolution',300)
exportgraphics(f6,'C vs t_cl.pdf','Resolution',300)
stop
%%
f7=figure
scatter(t0,cumsum(T(:,2)),50,'ro','filled')
hold on
scatter(t0,cumsum(T(:,3)),75,'bs','filled')
scatter(t0,cumsum(T(:,4)),50,'gd','filled')
ylabel("Concentration cumulative (mg/l)");
xlabel("time (days)");
grid on
box on
set(gca,'FontSize',16)
legend("S1","S2","S3","fontsize",14,'location','southeast')
exportgraphics(f7,'C vs t_cumulative.png')

%% Calculation of Diffusion coefficient
washed=T(1:2,:);
washed_sum=cumsum(washed);

T=T(3:end,:); %remove first 2 points


T_cum=cumsum(T);
save("T_sum.mat",'T_cum')
%con_cum=con_cum(3:end,:);
%t=[0.083 0.208 1 1.978 3.022 4 4.988 6 6.999 8.014 9.003 10];
t=[ 1 1.978 3.022 4 4.988 6 6.999 8.014 9.003 10];
m=2*1.59/(pi()^0.5);
%A0=[2547.804 2647.63 2313.29];


%CFL=(con_cum)/(m/A0);
CFL=T_cum./A0.*Vl;
t3=[0:0.05:10];

CCC=CFL(:,1);

%% non linear data fit
F=@(x,xdata)m*(x(1)*xdata).^0.5;
x0=0.01;

[x1,resnorm,~,exitflag,output] = lsqcurvefit(F,x0,t,CFL(:,2)')
[x2,resnorm,~,exitflag,output] = lsqcurvefit(F,x0,t,CFL(:,3)')
[x3,resnorm,~,exitflag,output] = lsqcurvefit(F,x0,t,CFL(:,4)')


Er1=100.*((m*(x1*t).^0.5-CFL(:,1)')*(m*(x1*t).^0.5-CFL(:,2)')')/CFL(end,1)
Er2=100.*((m*(x2*t).^0.5-CFL(:,1)')*(m*(x2*t).^0.5-CFL(:,3)')')/CFL(end,1)
Er3=100.*((m*(x3*t).^0.5-CFL(:,1)')*(m*(x3*t).^0.5-CFL(:,4)')')/CFL(end,1)

fit=m*(x1*t).^0.5;
%% Concentration time series
B=figure
scatter((t'),CFL(:,2),'r^')
hold on
%plot(t,fit,'r')
plot(t3,F(x1,t3),'r')

scatter((t'),CFL(:,3),'g^')
plot(t3,F(x2,t3),'g')
scatter((t'),CFL(:,4),'b^')
plot(t3,F(x3,t3),'b')

%% Comparison with a linear regression

[D1,r1,Er_1]=Linreg(t',CFL(:,2)/m) 
[D2,r2,Er_2]=Linreg(t',CFL(:,3)/m)
[D3,r3,Er_3]=Linreg(t',CFL(:,4)/m)

f4=figure
scatter((t'),CFL(:,2),50,'ro','filled')
hold on
plot(t3,sqrt(D1*t3)*m,'r--','LineWidth',1.2)

scatter((t'),CFL(:,3),50,'bs','filled')
plot(t3,sqrt(D2*t3)*m,'b--','LineWidth',1.2)
scatter((t'),CFL(:,4),50,'gd','filled')
plot(t3,sqrt(D3*t3)*m,'g--','LineWidth',1.2)
grid on
legend("S1 exp","S1 fit", "S2 exp","S2 fit","S3 exp","S3 fit","Location",'southeast','fontsize',14)
set(gca,'fontsize',16)
xlabel('Time[days]');
ylabel('Cumulative fraction diffused')
box on


Diffusion_coeff=[D1 D2 D3]/86400 %cm2/s
exportgraphics(f4,'Combined analysis Fitting.png')


% A=figure
% plot(Data(:,1), Data(:,3),'b'); %blank
% hold on
% plot(Data(:,1), Data(:,5),'Color',[1 0.9 0.9]); %T6t1
% plot(Data(:,1), Data(:,3), 'Color',[1 0.8 0.8]); %T6t2
% plot(Data(:,1), Data(:,6),'color', [1 0.7 0.7]); %T6t3
% plot(Data(:,1), Data(:,7), 'color', [1 0.65 0.65]); %T6t4
% plot(Data(:,1), Data(:,8), 'color', [1 0.55 0.55]); %T6t5
% plot(Data(:,1), Data(:,9),'color', [1 0.45 0.45]); %T6t6
% plot(Data(:,1), Data(:,10),'color', [1 0.35 0.35]); %T6t7
% plot(Data(:,1), Data(:,11),'color', [1 0 0]); %T6t8
% 
% legend('blank',"t1","t2","t3","t4","t5","t6","t7","t8")
% 
% set(gcf,'DefaultLineLineWidth',4)
x_sq=CFL(:,1).^2;




%% Comparison with CWE at the end of the test

Initial_CWE=[56.48 51.51 58.14];
mean_initial=mean(Initial_CWE);

%From leaching test
Fraction_left_LT=1-Total_diffused_mg./A0

%from CWE
Fraction_left_CWE=total_left/mean_initial
Bar=[Fraction_left_LT(2:4)' Fraction_left_CWE(2:4)']*100
%Bar=[Total_diffused_mg(2:4)' Initial_CWE']
f100=figure
bar(Bar);
xticklabels({'S1','S2', 'S3'})
legend('Leaching test', 'Cold water extraction','location','northwest','fontsize',14)
ylabel('Chloride remaining [%]')
set(gca,'fontsize',16)
ylim([0 50]);
saveas(f100,'CWE comparison.png')
%%
Initial_CWE=[56.48 51.51 58.14]./35.45;
mean_initial=mean(Initial_CWE);
std_initial=std(Initial_CWE);

%From leaching test
A1=A0./35.45; %mmol
mean_Initial_l=mean(A1(2:4));
std_initial_l=std(A1(2:4));

err=[std_initial; std_initial_l]
%from CWE
Bar=[mean_initial; mean_Initial_l]

f100=figure
bar(Bar);
hold on 
b = bar(Bar, 'grouped');
% Calculate the number of groups and number of bars in each group
[ngroups,nbars] = size(Bar);
% Get the x coordinate of the bars
x = nan(nbars, ngroups);
for i = 1:nbars
    x(i,:) = b(i).XEndPoints;
end

errorbar(x',Bar,err,'k','linestyle','none');

xticklabels({'CWE','Leaching test',})
%legend( 'Cold water extraction','Leaching test','location','northwest','fontsize',14)
ylabel('mmol')
set(gca,'fontsize',16)
%ylim([0 500]);
saveas(f100,'CWE comparison_initial.png')

%% Distribution of inhibitor: washing, diffused, left
f200=figure

fraction_diffused=(Total_diffused_mg-total_washed_mg)./A0;
fraction_washed=total_washed_mg./A0;


dist=[fraction_washed(2:4)' fraction_diffused(2:4)' Fraction_left_LT(2:4)']*100

bar(dist);
xticklabels({'S1','S2', 'S3'})
legend('Surface washing', 'Diffusion','Remaining','location','best','fontsize',14)
ylabel('Cl/Cl_0 [%]')
set(gca,'fontsize',16)
title('Chloride distribution');
ylim([0 100]);
saveas(f200,'Distribution_inhibitor.png')


% 
% %% figure
% fff=figure
% 
% fe=[416.4 505.44; 50.63 491.48]
% bar(fe);
% xticklabels({'A','CA'})
% legend('pH 7', 'pH 13','location','northeast','fontsize',14)
% ylabel('Na_4Fe(CN)_6 [mg/l]')
% set(gca,'fontsize',16)
% title('Release at day 7');
% ylim([0 800])
% 
% saveas(fff,'release.png')
%% IC non-linear fit




function [D,R,Er]=Linreg(x,y)
y_sq=y.^2;
D=x\y_sq;
yfit=x*D;
%D=D/86400; 
Er=(yfit-y_sq)'*(yfit-y_sq)/y_sq(end)*100

R=1 - sum((y_sq - yfit).^2)/sum((y_sq - mean(y_sq)).^2)
end

