clear all
tic

%Read data


FeCN_aw=484.06; %molecular weight
Cl_aw=35.45; %atomic weight g/mol
load("con_UV.mat"); %data from NaFeCN leaching test
load("T.mat"); %Data from chloride leaching test
t0=[0.083 0.208 1 1.978 3.022 4 4.988 6 6.999 8.014 9.003 10]; %each renewal time interval
T=(T-T(:,1));
A0_cl=[61.65 64.19 67.06]; % initial amount of chlorides from Cold water extraction test in each specimen
A0_In=[298.24 294.80 348.94]; % initial amount of inhibitor (FeCN) from Cold water extraction test in each specimen

Vl_In=[452.703 435.63 498.59]/1000; %Volume of leachant used for each renewal in L
Vl_cl=[469.76 498.79 504.75]/1000; %Volume of leachant used for each renewal in L

%%


%% Plot concentration in time
% f=figure
% plot(t0,T_cum(:,1),'ko-','LineWidth',1.2)
% hold on
% plot(t0,T_cum(:,2),'ro-','LineWidth',1.2)
% plot(t0,T_cum(:,3),'bo-','LineWidth',1.2)
% plot(t0,T_cum(:,4),'go-','LineWidth',1.2)
% ylabel("Concentration (mg/l)");
% xlabel("time (days)");
% hold off
% grid on
% title('Fe ICP')
% set(gca,'FontSize',16)
% legend('Control',"S1","S2","S3","fontsize",14)
% 
% exportgraphics(f,'C vs t_ICP_fe.png')
%%
% ff=figure
% plot(Na.Time,Na.T1,'ko-','LineWidth',1.2)
% hold on
% plot(Na.Time,Na.T2,'ro-','LineWidth',1.2)
% plot(Na.Time,Na.T3,'bo-','LineWidth',1.2)
% plot(Na.Time,Na.T4,'go-','LineWidth',1.2)
% ylabel("Concentration (mg/l)");
% xlabel("time (days)");
% hold off
% grid on
% title('Na ICP')
% set(gca,'FontSize',16)
% legend('Control',"I1","I2","I3","fontsize",14)
% 
% exportgraphics(ff,'C vs t_ICP_Na.png')
%% Comparison of UV-VIS

%ICP Fe in moles
%con(1:2,:)=[]
%T(1:2,:)=[]
%t0=[ 1 1.978 3.022 4 4.988 6 6.999 8.014 9.003 10];
I=cumsum(con)/1000/FeCN_aw; %NafeCN concentration in moles
S=cumsum(T)/1000/Cl_aw; %Cl in moles
%I_all=[I(:,1);I(:,2);I(:,3)];



I_avg=mean(I*1000,2);
I_sd=std(I*1000,0,2);

S=S(:,2:4); %remove control specimen
S_avg=mean(S*1000,2);
S_sd=std(S*1000,0,2);

f5=figure

errorbar(t0,I_avg,I_sd,'rx','LineWidth',1.2,'LineStyle','-')
hold on
errorbar(t0,S_avg,S_sd,'bx','LineWidth',1.2,'LineStyle','-')
xlabel('Time [days]');
ylabel('Concentration [mmol L^{-1}]');

legend('Fe(CN)_6^{4-}','Cl^-','location','northeast','fontsize',14)
set(gca,'fontsize',16)
box on
ylim([0 5])
exportgraphics(f5,'comparison_errorbars.png')
exportgraphics(f5,'comparison_errorbars.tif')
%%
I_CFL=cumsum(con)./A0_In.*Vl_In; %calculation of CFL NaFeCN
S_CFL=cumsum(T(:,2:4))./A0_cl.*Vl_cl; %calculation of CFL Cl

I_CFL_avg=mean(I_CFL,2);
I_CFL_sd=std(I_CFL,0,2);

S_CFL_avg=mean(S_CFL,2);
S_CFL_sd=std(S_CFL,0,2);


%% Non linear regression for calculating the diffusion coefficient
[b1,I_fit,Rsq_I,MSE_I,N1]=pescatore(t0,I_CFL_avg',[0.1],1.625, 5.166); %pescatore(x,y,b0,R,H) R and H in cm
[b2,S_fit,Rsq_S,MSE_S,N2]=pescatore(t0,S_CFL_avg',[0.1],1.604,5.701);

f8=figure

t1=0:0.1:10; %time interval for fitted data

errorbar(t0,I_CFL_avg,I_CFL_sd,'r','LineWidth',1.2,'LineStyle','none')
hold on
plot(t1,I_fit,'r--','LineWidth',1.2)
errorbar(t0,S_CFL_avg,S_CFL_sd,'b','LineWidth',1.2,'LineStyle','none')
plot(t1,S_fit,'b--','LineWidth',1.2)
hold off



xlabel('Time [days]');
ylabel('Cumulative fraction leached');
grid off
legend('Fe(CN)_6^{4-}','Fe(CN)_6^{4-} fit','Cl^-','Cl^- fit','location','southeast','Orientation','horizontal','NumColumns',2,'fontsize',16)

txt1 = sprintf('R^2= %0.2f',Rsq_S);
txt2 =sprintf('R^2= %0.2f',Rsq_I);
text(1,0.95,txt1,'FontSize',14)
text(4,0.45,txt2,'FontSize',14)

txt11 = sprintf('D_e= %.2e cm^2/s',b2/86400);
txt22 =sprintf('D_e= %.2e cm^2/s',b1/86400);
text(1,0.85,txt11,'FontSize',14)
text(4,0.55,txt22,'FontSize',14)
set(gca,'fontsize',18)
disp(b1/86400);
disp(b2/86400);

exportgraphics(f8,'Comparison_fit_pescatore_GA.tif','Resolution',300)
exportgraphics(f8,'Comparison_fit_pescatore_GA.pdf','Resolution',300)


%% graphical abstract
% f9=figure
% 
% t1=0:0.1:10;
% 
% errorbar(t0,I_CFL_avg,I_CFL_sd,'r','LineWidth',1.2,'LineStyle','none')
% hold on
% plot(t1,I_fit,'r--','LineWidth',1.5)
% %errorbar(t0,S_CFL_avg,S_CFL_sd,'b','LineWidth',1.2,'LineStyle','none')
% %plot(t1,S_fit,'b--','LineWidth',1.2)
% hold off
% 
% 
% 
% xlabel('Time [days]');
% ylabel('Cumulative fraction leached');
% grid off
% legend('Fe(CN)_6^{4-} measured','Fe(CN)_6^{4-} fit','location','southeast','Orientation','vertical','fontsize',16)
% 
% %txt1 = sprintf('R^2= %0.2f',Rsq_S);
% txt2 =sprintf('R^2= %0.2f',Rsq_I);
% %text(1,0.95,txt1,'FontSize',14)
% text(4,0.45,txt2,'FontSize',14)
% 
% %txt11 = sprintf('D_e= %.2e cm^2/s',b2/86400);
% txt22 =sprintf('D_e= %.2e cm^2/s',b1/86400);
% %text(1,0.85,txt11,'FontSize',14)
% text(4,0.55,txt22,'FontSize',14)
% set(gca,'fontsize',18)
% disp(b1/86400);
% %disp(b2/86400);
% 
% exportgraphics(f9,'graphical abstract.tif','Resolution',300)
% %exportgraphics(f9,'graphical abstract.pdf','Resolution',300)


%% Comparison of remaining species
f100=figure 
Bar1=[18.072 23.206; 6.79 7.90];
err1=[1.77 3.6; 0.45 0.83];

hold on 
b = bar(Bar1, 'grouped');
% Calculate the number of groups and number of bars in each group
[ngroups,nbars] = size(Bar1);
% Get the x coordinate of the bars
x = nan(nbars, ngroups);
for i = 1:nbars
    x(i,:) = b(i).XEndPoints;
end

errorbar(x',Bar1,err1,'k','linestyle','none','LineWidth',1);
xticks([1 2])
xticklabels({'Fe(CN)_6^{4-}','Cl^-',})
legend( 'Leaching test','Cold water extraction','location','northeast','fontsize',14)
ylabel('Inhibitor remaining [%]')
set(gca,'fontsize',16)
box on
ylim([0 50]);
exportgraphics(f100,'CWE comparison_In vs S_errorbars.tif','Resolution',300)

exportgraphics(f100,'CWE comparison_In vs S_errorbars.pdf','Resolution',300)



%% Function definitions
%calculation of R2
function [D,R,Er]=Linreg(x,y)
y_sq=y.^2;
D=x\y_sq;
yfit=x*D;
%D=D/86400; 
Er=(yfit-y_sq)'*(yfit-y_sq)/y_sq(end)*100

R=1 - sum((y_sq - yfit).^2)/sum((y_sq - mean(y_sq)).^2)
end
