%Diffusion coefficient fitting as per ASTM C1308-08
%inputs x=time, y=CFL, b0=initial guess of the diffusion coeffcient
%Output: b=diffusion coefficient from the fitting
%qt=fitted data using b
% Rsq=R2
%MSE=mean squared error

function [b,qt,Rsq,MSE,n]=pescatore(x,y,b0,R,H)

    b = fminsearch(@(b) fn(b,x,y), b0); %Minimisation of error using fminsearch (Simplex algorithm)
    disp(b)
    t = 0:0.1:10; %for the fitted data
    qt = qt_fn(t,b);
    yfit=qt_fn(x,b);
    MSE=(yfit-y)*(yfit-y)'/y(end)*100 %mean squared error

    Rsq=1 - sum((y - yfit).^2)/sum((y - mean(y)).^2) %calculating r^2

    %figure
    %plot(x,y,'bo',t,qt), grid
    %xlabel('t'),ylabel('CFl')
    function F = fn(b,x,y)
            q = qt_fn(x, b);
            F = norm(y - q); %minimisation cost function
             
    end
    function qt = qt_fn(t, b)
             N = 1000;  %number of terms
             term = 0;
             St = 0;
             err = 1;
             n = 1;
             %R=1.57;%cm
             %H=5.55;%cm
    
             while (err>10^-16) & (n<=N) %tolerance
               oldterm = term;
              
               term = (exp(-((2*n-1)*pi()/H)^2.*b(1).*t))/(2*n-1).^2; %anaylitical solution as per nestor, Fourier
               St = term + St;
               n = n+1;
               err = abs(term-oldterm);
             end
    
               beta=[2.40482 5.5200 8.6537 11.7915 14.9309 18.0710 21.2116 24.3524 27.4934 30.6346 33.7758 36.9170 40.0584 43.1997 46.3411 49.4826 52.6240 55.7655 58.9069 62.0484]; %Bessel function ASTM C1308
               Sc=0; 
               for m=1:20
                Sc1=(exp(-(beta(m)./R).^2.*b(1).*t))/(beta(m)).^2; %anaylitical solution as per nestor, Bessel
                Sc=Sc+Sc1;
                end
             %Sc=1;
             qt = 1-32/(pi()).^2.*St.*Sc; %analytical solution as per nestor
    end
end