
clear all
tic
%MORISAL water absorption coefficient computation
%Code will compute WAC as the intersection of two absorption curves.
%absorption curves are found using Linear regression
%Read data

Data=readtable('WAC_characterisation.xlsx','sheet','Char_WAC','range','A14:J23'); %mi-md
%Data=readtable('WAC_initial drying.xlsx','sheet','NHL_WAC test','range','A2:M11');%MI
A=readtable('WAC_characterisation.xlsx','sheet','Char_WAC','range','N13:V14');
md=readtable('WAC_characterisation.xlsx','sheet','Char_WAC','range','N1:V2'); %dry weight
%AA=table2array(A);
AA=[1 1 1 1 1 1 1 1 1]
md_ar=table2array(md);
%md_mean=[mean(md_ar(1:4)) mean(md_ar(5:8)) mean(md_ar(8:12))] ; %mean for each concentration
%AA=(ones(1,12));
[Control, Control_WAC,Control_WAC_final]=computeWAC(Data.T,Data(:,2:4),AA(1:3),md_ar(1:3)); %Ref
[P1, P1_WAC, P1_WAC_final]=computeWAC(Data.T,Data(:,5:7),AA(4:6),md_ar(4:6)); % Salt
[P2, P2_WAC, P2_WAC_final]=computeWAC(Data.T,Data(:,8:10),AA(7:9),md_ar(7:9)); % 10% Inhibitor
WAC_NHL=[Control_WAC P1_WAC P2_WAC];

%%
%Plot
f=figure;
errorbar(sqrt(Data.T),Control(:,1),Control(:,2), 'r^-','MarkerFaceColor','r','LineWidth',1);
hold on
errorbar(sqrt(Data.T),P2(:,1),P2(:,2), 'g^-','MarkerFaceColor','g','LineWidth',1);%inhibitor
errorbar(sqrt(Data.T),P1(:,1),P1(:,2), 'b^-','MarkerFaceColor','b','LineWidth',1);%salt


%Intersection
scatter(Control_WAC(1),Control_WAC(2),75,'rx');
scatter(P2_WAC(1),P2_WAC(2),75,'gx');
scatter(P1_WAC(1),P1_WAC(2),75,'bx');

grid on
xlabel('\surdt [min^{0.5}]','Interpreter','tex');
ylabel('Water absorption [% M_d]')
legend('R','I','S','location','southeast','FontSize',14);
%title('Capillary absorption');
ylim([0 15]);
yticks([0:3:15])
set(gca,'FontSize',16);
exportgraphics(f,'NHL_WAC_area_CHAR.tiff','resolution',300);
exportgraphics(f,'NHL_WAC_area_CHAR.pdf','resolution',300);
%%
WAC_final=(WAC_NHL(2,:))./(WAC_NHL(1,:)*sqrt(60)); %min^05 converted to s^0.5
toc


function [ct,WAC,WAC_final]=computeWAC(Time,D,Area,dry_mass) 
%Time= time vector in t^0.5 m, D=Data for computation is already (mi-md)/md, A=Surface area vector in m2]

D_array=(table2array(D))./Area;
M=mean(D_array,2);
s=std(D_array,0,2);
t=[ones(size(Time,1),1) sqrt(Time)]; 
B1=t(1:5,:)\M(1:5,:); %Linear regression stage 1
B2=t(6:end,:)\M(6:end,:); %Linear regression stage 2
%Solve equations obtained from linear regressions to find intersection
B=[-B1(2) 1; -B2(2) 1]; %coefficient matrix X
B0=[B1(1); B2(1)]; %Coefficient Matrix Intercept
WAC=B\B0; %Solve for intersection point [t,W]

%Calculation of the water absorpition coefficient as per the standard
md=mean(dry_mass./Area); %dry mass normalised to wetting area
WAC_final=1; %in g/m2/s^0.5
%WAC_final=(WAC(2,:)./(WAC(1,:)*sqrt(60)); %in g/m2/s^0.5
ct=[M,s]; %Return
end





